@@ -4,7 +4,8 @@ import logging
 import simple_audit
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
-from django_extensions.db.fields.encrypted import EncryptedCharField
+from django_extensions.db.fields.encrypted import (EncryptedCharField,
+                                                   EncryptedTextField)
 from util.models import BaseModel
 from physical.models import Environment
 
@@ -39,7 +40,7 @@ class CredentialType(BaseModel):
     ACLFROMHELL = 28
     TELEGRAF = 29
     VIP_PROVIDER = 30
-    KIBANA_LOG = 32
+    KUBERNETES = 31
 
     INTEGRATION_CHOICES = (
         (CLOUDSTACK, 'Cloud Stack'),
@@ -67,7 +68,7 @@ class CredentialType(BaseModel):
         (ACLFROMHELL, 'Acl from hell'),
         (TELEGRAF, 'Telegraf'),
         (VIP_PROVIDER, 'Vip Provider'),
-        (KIBANA_LOG, 'Kibana Log'),
+        (KUBERNETES, 'Kubernetes'),
     )
     name = models.CharField(verbose_name=_("Name"),
                             max_length=100,
@@ -90,6 +91,9 @@ class Credential(BaseModel):
     password = EncryptedCharField(
         verbose_name=_("Password"), max_length=255, blank=True, null=True
     )
+    config = EncryptedTextField(
+        verbose_name=_("Config"), blank=True, null=True
+    )
     integration_type = models.ForeignKey(
         CredentialType, related_name="integration_type",
         on_delete=models.PROTECT
